var _reactJsxRuntime = require("react/jsx-runtime");
/*#__PURE__*/_reactJsxRuntime.jsx("div", {});
